@@ -15,6 +15,9 @@ class Bundle:
         'require_share_recipient': None,     # boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
         'clickwrap_body': None,     # string - Legal text that must be agreed to prior to accessing Bundle.
         'form_field_set': None,     # FormFieldSet - Custom Form to use
+        'skip_name': None,     # boolean - BundleRegistrations can be saved without providing name?
+        'skip_email': None,     # boolean - BundleRegistrations can be saved without providing email?
+        'skip_company': None,     # boolean - BundleRegistrations can be saved without providing company?
         'id': None,     # int64 - Bundle ID
         'created_at': None,     # date-time - Bundle created at date/time
         'expires_at': None,     # date-time - Bundle expiration date/time
@@ -90,6 +93,9 @@ class Bundle:
     #   preview_only - boolean - Restrict users to previewing files only?
     #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
     #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+    #   skip_email - boolean - BundleRegistrations can be saved without providing email?
+    #   skip_name - boolean - BundleRegistrations can be saved without providing name?
+    #   skip_company - boolean - BundleRegistrations can be saved without providing company?
     #   watermark_attachment_delete - boolean - If true, will delete the file stored in watermark_attachment
     #   watermark_attachment_file - file - Preview watermark image applied to all bundle items.
     def update(self, params = None):
@@ -226,6 +232,9 @@ def get(id, params = None, options = None):
 #   clickwrap_id - int64 - ID of the clickwrap to use with this bundle.
 #   inbox_id - int64 - ID of the associated inbox, if available.
 #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+#   skip_email - boolean - BundleRegistrations can be saved without providing email?
+#   skip_name - boolean - BundleRegistrations can be saved without providing name?
+#   skip_company - boolean - BundleRegistrations can be saved without providing company?
 #   watermark_attachment_file - file - Preview watermark image applied to all bundle items.
 def create(params = None, options = None):
     if not isinstance(params, dict):
@@ -298,6 +307,9 @@ def share(id, params = None, options = None):
 #   preview_only - boolean - Restrict users to previewing files only?
 #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
 #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+#   skip_email - boolean - BundleRegistrations can be saved without providing email?
+#   skip_name - boolean - BundleRegistrations can be saved without providing name?
+#   skip_company - boolean - BundleRegistrations can be saved without providing company?
 #   watermark_attachment_delete - boolean - If true, will delete the file stored in watermark_attachment
 #   watermark_attachment_file - file - Preview watermark image applied to all bundle items.
 def update(id, params = None, options = None):
